@@ -130,7 +130,7 @@ fn print_local(
     adjust_offset(stdout, config)?;
 
     // get the desired width and height
-    let (w, h) = find_best_fit(&img, config.width, config.height);
+    let (w, h) = find_best_fit(img, config.width, config.height);
 
     write!(
         stdout,
@@ -164,7 +164,7 @@ fn print_remote(
 
     adjust_offset(stdout, config)?;
 
-    let (w, h) = find_best_fit(&img, config.width, config.height);
+    let (w, h) = find_best_fit(img, config.width, config.height);
 
     let first_chunk: String = iter.by_ref().take(4096).collect();
 
